--- title: Notebook template keywords: fastai sidebar: home_sidebar summary: "A minimal template for a new nbdev-Colab notebook " ---
{% raw %}

    #all_flag
    # remove this cell to use with tests

    # #hide
    # optional user defined test_flag here
    from google.colab import drive
    drive.mount('/content/drive')

    # #hide
    %load_ext autoreload
    %autoreload 2

    # #hide
    !pip install nbdev
    !pip install fastcore

    # #hide
    # add repo name then remove this comment
    %cd /content/drive/My drive/<repo name>

    # #hide
    #not deps but we need them to use nbdev and run tests
    from nbdev import *
    from nbdev.showdoc import *
    from fastcore.test import *

    # #hide
    # optional build script code - not required if you manage your project from another dedicated notebook.
    from nbdev.export import notebook2script
    notebook2script()

{% endraw %}